# 📦 React Tailwindcss Date-Time Picker

This is a feature rich React date-time picker component which supports:

    1. Selecting a date range from calendar
    2. Selecting time for both start and end of the range
    3. Defining custom range presets for quicker access
    4. keyboard accessibility - Arrow key and Tab navigation
    
It's a fork of [react-datetimepicker](https://github.com/v0ltoz/react-datetimepicker) but completely re-written with React 18 (Can be used in strict mode), [Tailwindcss](https://tailwindcss.com/) and build with blazing fast [Vitejs](https://vitejs.dev/).


<a href="https://github.com/microsoft/react-native-macos/blob/master/LICENSE">
    <img src="https://img.shields.io/badge/license-MIT-blue.svg" alt="React Native for macOS is released under the MIT license." />
  </a>
<a href="https://www.npmjs.com/package/raygun-sourcemap-webpack-plugin">
    <img src="https://img.shields.io/npm/dm/raygun-sourcemap-webpack-plugin.svg?style=flat-square" alt="Downloads" />
</a>

## Online Demo
**See a working demo at codesandbox.io**
It will work with React Version 18+

https://codesandbox.io/s/zxoo178m03?fontsize=14&module=%2Fsrc%2FApp.js



![Date Time Picker](https://raw.githubusercontent.com/mohsentaleb/react-tailwindcss-datetimepicker/master/public/date-picker-screenshot.png)


## Setup
Install via npm: 
```bash
npm i react-tailwindcss-datetimepicker
```
or Yarn

```bash
yarn add react-tailwindcss-datetimepicker
```

## Properties Required

**ranges** {React.Object}  
Object of ranges that will be you default ranges. Example:
```js
let ranges = {
            "Today Only": [moment(start), moment(end)],
            "Yesterday Only": [moment(start).subtract(1, "days"), moment(end).subtract(1, "days")],
            "3 Days": [moment(start).subtract(3, "days"), moment(end)]
        }
```
**start (Required)** {Moment Object}  
Initial Start Date that will be selected, should be a moment object

**end (Required)** {Moment Object}  
Initial End Date that will be selected, should be a moment object

**local (Required)** {Object}  
Defines a local format for date labels to be shown as. Can also set Sunday to be first day or Monday. Local object accepts format and sunday first params. 

--> format: moment display format <br>
--> sundayFirst: True Sunday the first day of the week. False, Monday first day of the week. <br>
--> <b>From release version 1.0.7+</b>: days, months, fromDate, toDate, selectingFrom, selectingTo, MaxDate, close, apply, cancel <br>

```js
let local = {
    "format":"DD-MM-YYYY HH:mm",
    "sundayFirst" : false,
    days: ['Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa', 'So'],
    months: [
        'January',
        'February',
        'March',
        'April',
        'May',
        'June',
        'July',
        'August',
        'September',
        'October',
        'November',
        'December',],
    fromDate: 'From Date',
    toDate: 'To Date',
    selectingFrom: 'Selecting From',
    selectingTo: 'Selecting To',
    maxDate: 'Max Date',
    close: 'Close',
    apply: 'Apply',
    cancel: 'Cancel'
}
```

**applyCallback (Required)** {React.func} <br>
Function which is called when the apply button is clicked/pressed. Takes two params, that start date and the end date.

```js
func applyCallback(startDate, endDate){
    ... 
}
```

**maxDate (optional)** {Moment Object} <br>
Maximum date that can be selected. 

**rangeCallback (optional)** {React.func} <br>
```js
func rangeCallback(index, value) {
    ...
}
```

**autoApply (optional)** {bool} <br>
When set there will only be one button in the bottom right to close the screen. 
Whenever a button is clicked in the date picker the apply callback
function will be called for you.

**descendingYears (optional)** {bool} <br>
When set the years will be displayed in descending order on the picker instead of ascending order.

**years (optional)** {array} <br>
years={[2010, 2020]}
Takes an array where the first value is the start year and the second values is the end year. This will 
update the dropdown years to only show these years. 
<br> WARNING: This does not affect the ability to type in years in the text box and go beyond the values set here.

**smartMode (optional)** {bool} <br>
The date time picker will switch the month on the RHS when two dates in the same month are selected. Can be used in 
conjunction with pastSearchFriendly to switch the month on the LHS when the two dates are from the same month.


**pastSearchFriendly (optional)** {bool} <br>
Requires: Smart Mode enabled
<br>
Changes the mode of the date time picker to be optimised for past searches.
Where possible the start and end time will be shown on the RHS 
when the month and year are equal. This allows for  the previous month to be 
shown on the LHS to allow easier backwards searching. 
<br>
This setting is false by default meaning that the LHS is used when dates are selected in the same month & year 

**style (optional)** {Object} <br>
Allows custom styling of some of the elements of the date time picker. The following can be added:
```js
{
    fromDot: {backgroundColor: 'rgb(100, 0, 34)'},
    toDot: {backgroundColor: 'rgb(0, 135, 255)'},
    fromDate: {color: 'rgb(0, 255, 100)', backgroundColor: 'rgb(255, 100, 100)'},
    toDate: {backgroundColor: 'rgb(40, 90, 75)'},
    betweenDates: {color: 'rgb(200, 0, 34)', backgroundColor: 'rgb(200, 150, 100)'},
    hoverCell: {color: 'rgb(200, 0, 34)'},
    customRangeButtons: {backgroundColor: 'rgb(40, 90, 75)'},
    customRangeSelected: {backgroundColor: 'rgb(100, 90, 200)'},
    standaloneLayout:{display:'flex', maxWidth:'fit-content'}
}
```

**darkMode (optional)** {bool} <br>
Changes the DateTimePicker to be in Dark Mode, default is Light Mode

**noMobileMode (optional)** {bool} <br>
Release Version: 1.0.6+ <br>
When set the mobile/condense breakpoint will be ignored meaning the component will stay
in full screen mode all the time.

**forceMobileMode (optional)** {bool} <br>
Release Version: 1.0.9+ <br>
When set the mobile/condense breakpoint will be ignored meaning the component will stay
in condensed mode all the time.

**twelveHoursClock (optional)** {bool} <br>
Release Version: 1.0.13+ <br>
When set the picker time values will be in 12 hour mode not 24 hour mode

**standaloneMode (optional)** {bool} <br>
Release Version: 1.0.9+ (BETA) <br>
When set the picker will be open by default and follow the styling given. This config option
requires the below config styling to also be present in order
to style the div

``` js
style={{
    standaloneLayout:{display:'flex', maxWidth:'fit-content'}
}}
```

**leftMode (optional)** {bool} <br>
Release Version: 1.0.6+ (BETA) <br>
When set and changed the picker will open to the left (right to left) instead of the default which is to open to the right (left to right)

**centerMode  (optional)** {bool} <br>
Release Version: 1.0.14+ (BETA) <br>
To allow flexibility, center mode has been added where leftMode or default is not enough.

## Getting Started

```js
import React from 'react';
import DateTimeRangeContainer from 'react-advanced-datetimerange-picker'
import {FormControl} from 'react-bootstrap'
import moment from "moment"

class Wrapper extends React.Component {

    constructor(props){
        super(props);
        let now = new Date();
        let start = moment(new Date(now.getFullYear(), now.getMonth(), now.getDate(), 0,0,0,0));
        let end = moment(start).add(1, "days").subtract(1, "seconds");
        this.state = {
            start : start,
            end : end
        }

        this.applyCallback = this.applyCallback.bind(this);
    }

    applyCallback(startDate, endDate){
        this.setState({
                start: startDate,
                end : endDate
            }
        )
    }

    render(){
            let now = new Date();
            let start = moment(new Date(now.getFullYear(), now.getMonth(), now.getDate(), 0,0,0,0));
            let end = moment(start).add(1, "days").subtract(1, "seconds");
            let ranges = {
                "Today Only": [moment(start), moment(end)],
                "Yesterday Only": [moment(start).subtract(1, "days"), moment(end).subtract(1, "days")],
                "3 Days": [moment(start).subtract(3, "days"), moment(end)]
            }
            let local = {
                "format":"DD-MM-YYYY HH:mm",
                "sundayFirst" : false
            }
            let maxDate = moment(start).add(24, "hour")
            return(
                <div>
                    <DateTimeRangeContainer 
                        ranges={ranges}
                        start={this.state.start}
                        end={this.state.end}
                        local={local}
                        maxDate={maxDate}
                        applyCallback={this.applyCallback}
                    >    
                        <FormControl
                        id="formControlsTextB"
                        type="text"
                        label="Text"
                        placeholder="Enter text"
                        /> 
                    </DateTimeRangeContainer>
                </div>
            );
        }
}
```


## Available Scripts

In the project directory, you can run:

### `npm start`

Runs the app in the development mode.<br>
Open [http://localhost:3000](http://localhost:3000) to view it in the browser.

The page will reload if you make edits.<br>
You will also see any lint errors in the console.

### `npm test`

Launches the test runner in the interactive watch mode.<br>
See the section about [running tests](https://facebook.github.io/create-react-app/docs/running-tests) for more information.

### `npm run build`

Builds the app for production to the `build` folder.<br>
It correctly bundles React in production mode and optimizes the build for the best performance.

### npm test -- --coverage

Gets test coverage when running tests to see how much of the code is covered by your tests.